gluonts\.dataset\.artificial package
====================================

Submodules
----------

gluonts\.dataset\.artificial\.\_base module
-------------------------------------------

.. automodule:: gluonts.dataset.artificial._base
    :members:
    :undoc-members:
    :show-inheritance:

gluonts\.dataset\.artificial\.generate\_synthetic module
--------------------------------------------------------

.. automodule:: gluonts.dataset.artificial.generate_synthetic
    :members:
    :undoc-members:
    :show-inheritance:

gluonts\.dataset\.artificial\.recipe module
-------------------------------------------

.. automodule:: gluonts.dataset.artificial.recipe
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: gluonts.dataset.artificial
    :members:
    :undoc-members:
    :show-inheritance:
